@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Util::Test::KENTNL;
 
-our $VERSION = '1.000003';
+our $VERSION = '1.001001';
 
 #ABSTRACT: KENTNL's DZil plugin testing tool
 
@@ -14,8 +14,8 @@ our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 use Try::Tiny qw( try catch );
 use Dist::Zilla::Tester qw( Builder );
 use Sub::Exporter -setup => {
-  exports => [ 'test_config', ],
-  groups  => [ default => [qw( -all )] ],
+  exports => [ 'test_config', 'dztest' ],
+  groups => [ default => [qw( -all )] ],
 };
 use Test::DZil qw(simple_ini);
 
@@ -27,6 +27,20 @@ use Test::DZil qw(simple_ini);
 
 
 
+sub dztest {
+  my (@args) = @_;
+  require Dist::Zilla::Util::Test::KENTNL::dztest;
+  return Dist::Zilla::Util::Test::KENTNL::dztest->new(@args);
+}
+
+
+
+
+
+
+
+
+
 
 
 
@@ -196,10 +210,16 @@ Dist::Zilla::Util::Test::KENTNL - KENTNL's DZil plugin testing tool
 
 =head1 VERSION
 
-version 1.000003
+version 1.001001
 
 =head1 METHODS
 
+=head2 C<dztest>
+
+Creates a L<< C<Dist::Zilla::Util::Test::KENTNL>|Dist::Zilla::Util::Test::KENTNL::dztest >> object.
+
+This is a much more sane approach to testing than C<test_config>
+
 =head2 test_config
 
 This is pretty much why this module exists. Its a little perverse, but makes testing WAY easier.
